@@ -20,6 +20,12 @@ pub use graph::ModuleGraph;
 #[cfg(feature = "rust")]
 pub use graph::ModuleGraphError;
 use graph::ModuleSlot;
+#[cfg(feature = "wasm")]
+pub use js_graph::JsLoader;
+#[cfg(feature = "wasm")]
+pub use js_graph::JsLocker;
+#[cfg(feature = "wasm")]
+pub use js_graph::JsResolver;
 #[cfg(feature = "rust")]
 pub use media_type::MediaType;
 #[cfg(feature = "rust")]
@@ -35,10 +41,6 @@ use std::rc::Rc;
 #[cfg(feature = "wasm")]
 use wasm_bindgen::prelude::*;
 
-#[cfg(feature = "wee_alloc")]
-#[global_allocator]
-static ALLOC: wee_alloc::WeeAlloc = wee_alloc::WeeAlloc::INIT;
-
 /// Create a module graph, based on loanding and recursively analyzing the
 /// dependencies of the module, returning the resulting graph.
 #[cfg(feature = "rust")]
@@ -78,7 +80,7 @@ pub async fn js_create_graph(
   maybe_resolve: Option<js_sys::Function>,
   maybe_check: Option<js_sys::Function>,
   maybe_get_checksum: Option<js_sys::Function>,
-) -> js_graph::ModuleGraph {
+) -> Result<js_graph::ModuleGraph, JsValue> {
   let loader = Box::new(js_graph::JsLoader::new(load, maybe_cache_info));
   let maybe_resolver: Option<Box<dyn Resolver>> =
     if let Some(resolve) = maybe_resolve {
@@ -94,11 +96,12 @@ pub async fn js_create_graph(
       None
     };
   let root_specifier =
-    module_specifier::ModuleSpecifier::parse(&root_specifier).unwrap();
+    module_specifier::ModuleSpecifier::parse(&root_specifier)
+      .map_err(|err| JsValue::from(js_sys::Error::new(&err.to_string())))?;
   let builder =
     Builder::new(root_specifier, false, loader, maybe_resolver, maybe_locker);
   let graph = builder.build().await;
-  js_graph::ModuleGraph(graph)
+  Ok(js_graph::ModuleGraph(graph))
 }
 
 #[cfg(feature = "wasm")]
